@@ -36,7 +36,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddDBInstanceToReadOnlyGroup", params)
+            headers = request.headers
+            body = self.call("AddDBInstanceToReadOnlyGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddDBInstanceToReadOnlyGroupResponse()
@@ -64,7 +65,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CloneDBInstance", params)
+            headers = request.headers
+            body = self.call("CloneDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CloneDBInstanceResponse()
@@ -92,7 +94,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CloseDBExtranetAccess", params)
+            headers = request.headers
+            body = self.call("CloseDBExtranetAccess", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CloseDBExtranetAccessResponse()
@@ -120,7 +123,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CloseServerlessDBExtranetAccess", params)
+            headers = request.headers
+            body = self.call("CloseServerlessDBExtranetAccess", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CloseServerlessDBExtranetAccessResponse()
@@ -138,6 +142,35 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateDBInstanceNetworkAccess(self, request):
+        """可对实例进行网络的添加操作。
+
+        :param request: Request instance for CreateDBInstanceNetworkAccess.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.CreateDBInstanceNetworkAccessRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.CreateDBInstanceNetworkAccessResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateDBInstanceNetworkAccess", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateDBInstanceNetworkAccessResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateDBInstances(self, request):
         """本接口 (CreateDBInstances) 用于创建一个或者多个PostgreSQL实例,仅发货实例不会进行初始化。
 
@@ -148,7 +181,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDBInstances", params)
+            headers = request.headers
+            body = self.call("CreateDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDBInstancesResponse()
@@ -176,7 +210,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateInstances", params)
+            headers = request.headers
+            body = self.call("CreateInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateInstancesResponse()
@@ -204,7 +239,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateReadOnlyDBInstance", params)
+            headers = request.headers
+            body = self.call("CreateReadOnlyDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateReadOnlyDBInstanceResponse()
@@ -232,7 +268,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateReadOnlyGroup", params)
+            headers = request.headers
+            body = self.call("CreateReadOnlyGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateReadOnlyGroupResponse()
@@ -250,6 +287,35 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateReadOnlyGroupNetworkAccess(self, request):
+        """可对RO组进行网络的添加操作。
+
+        :param request: Request instance for CreateReadOnlyGroupNetworkAccess.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.CreateReadOnlyGroupNetworkAccessRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.CreateReadOnlyGroupNetworkAccessResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateReadOnlyGroupNetworkAccess", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateReadOnlyGroupNetworkAccessResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateServerlessDBInstance(self, request):
         """本接口 (CreateServerlessDBInstance) 用于创建一个ServerlessDB实例，创建成功返回实例ID。
 
@@ -260,7 +326,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateServerlessDBInstance", params)
+            headers = request.headers
+            body = self.call("CreateServerlessDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateServerlessDBInstanceResponse()
@@ -278,6 +345,35 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteDBInstanceNetworkAccess(self, request):
+        """可对实例进行网络的删除操作。
+
+        :param request: Request instance for DeleteDBInstanceNetworkAccess.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.DeleteDBInstanceNetworkAccessRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.DeleteDBInstanceNetworkAccessResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteDBInstanceNetworkAccess", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteDBInstanceNetworkAccessResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteReadOnlyGroup(self, request):
         """本接口(DeleteReadOnlyGroup)用于删除指定的只读组
 
@@ -288,7 +384,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteReadOnlyGroup", params)
+            headers = request.headers
+            body = self.call("DeleteReadOnlyGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteReadOnlyGroupResponse()
@@ -306,6 +403,35 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteReadOnlyGroupNetworkAccess(self, request):
+        """可对RO组进行网络的删除操作。
+
+        :param request: Request instance for DeleteReadOnlyGroupNetworkAccess.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.DeleteReadOnlyGroupNetworkAccessRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.DeleteReadOnlyGroupNetworkAccessResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteReadOnlyGroupNetworkAccess", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteReadOnlyGroupNetworkAccessResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteServerlessDBInstance(self, request):
         """本接口 (DeleteServerlessDBInstance) 用于删除一个ServerlessDB实例。
 
@@ -316,7 +442,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteServerlessDBInstance", params)
+            headers = request.headers
+            body = self.call("DeleteServerlessDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteServerlessDBInstanceResponse()
@@ -344,7 +471,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAccounts", params)
+            headers = request.headers
+            body = self.call("DescribeAccounts", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAccountsResponse()
@@ -372,7 +500,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAvailableRecoveryTime", params)
+            headers = request.headers
+            body = self.call("DescribeAvailableRecoveryTime", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAvailableRecoveryTimeResponse()
@@ -400,7 +529,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBackupPlans", params)
+            headers = request.headers
+            body = self.call("DescribeBackupPlans", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBackupPlansResponse()
@@ -428,7 +558,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCloneDBInstanceSpec", params)
+            headers = request.headers
+            body = self.call("DescribeCloneDBInstanceSpec", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCloneDBInstanceSpecResponse()
@@ -456,7 +587,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBBackups", params)
+            headers = request.headers
+            body = self.call("DescribeDBBackups", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBBackupsResponse()
@@ -484,7 +616,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBErrlogs", params)
+            headers = request.headers
+            body = self.call("DescribeDBErrlogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBErrlogsResponse()
@@ -512,7 +645,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBInstanceAttribute", params)
+            headers = request.headers
+            body = self.call("DescribeDBInstanceAttribute", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBInstanceAttributeResponse()
@@ -540,7 +674,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBInstanceParameters", params)
+            headers = request.headers
+            body = self.call("DescribeDBInstanceParameters", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBInstanceParametersResponse()
@@ -568,7 +703,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBInstances", params)
+            headers = request.headers
+            body = self.call("DescribeDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBInstancesResponse()
@@ -596,7 +732,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBSlowlogs", params)
+            headers = request.headers
+            body = self.call("DescribeDBSlowlogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBSlowlogsResponse()
@@ -624,7 +761,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBXlogs", params)
+            headers = request.headers
+            body = self.call("DescribeDBXlogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBXlogsResponse()
@@ -652,7 +790,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDatabases", params)
+            headers = request.headers
+            body = self.call("DescribeDatabases", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDatabasesResponse()
@@ -670,6 +809,35 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeEncryptionKeys(self, request):
+        """获取实例的密钥信息列表。
+
+        :param request: Request instance for DescribeEncryptionKeys.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.DescribeEncryptionKeysRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.DescribeEncryptionKeysResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeEncryptionKeys", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeEncryptionKeysResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeOrders(self, request):
         """本接口（DescribeOrders）用于获取订单信息。
 
@@ -680,7 +848,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeOrders", params)
+            headers = request.headers
+            body = self.call("DescribeOrders", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeOrdersResponse()
@@ -708,7 +877,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeParamsEvent", params)
+            headers = request.headers
+            body = self.call("DescribeParamsEvent", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeParamsEventResponse()
@@ -736,7 +906,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeProductConfig", params)
+            headers = request.headers
+            body = self.call("DescribeProductConfig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeProductConfigResponse()
@@ -764,7 +935,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeReadOnlyGroups", params)
+            headers = request.headers
+            body = self.call("DescribeReadOnlyGroups", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeReadOnlyGroupsResponse()
@@ -792,7 +964,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRegions", params)
+            headers = request.headers
+            body = self.call("DescribeRegions", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRegionsResponse()
@@ -820,7 +993,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeServerlessDBInstances", params)
+            headers = request.headers
+            body = self.call("DescribeServerlessDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeServerlessDBInstancesResponse()
@@ -848,7 +1022,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSlowQueryAnalysis", params)
+            headers = request.headers
+            body = self.call("DescribeSlowQueryAnalysis", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSlowQueryAnalysisResponse()
@@ -876,7 +1051,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSlowQueryList", params)
+            headers = request.headers
+            body = self.call("DescribeSlowQueryList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSlowQueryListResponse()
@@ -904,7 +1080,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeZones", params)
+            headers = request.headers
+            body = self.call("DescribeZones", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeZonesResponse()
@@ -932,7 +1109,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DestroyDBInstance", params)
+            headers = request.headers
+            body = self.call("DestroyDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DestroyDBInstanceResponse()
@@ -960,7 +1138,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DisIsolateDBInstances", params)
+            headers = request.headers
+            body = self.call("DisIsolateDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DisIsolateDBInstancesResponse()
@@ -988,7 +1167,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InitDBInstances", params)
+            headers = request.headers
+            body = self.call("InitDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InitDBInstancesResponse()
@@ -1016,7 +1196,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceCreateDBInstances", params)
+            headers = request.headers
+            body = self.call("InquiryPriceCreateDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceCreateDBInstancesResponse()
@@ -1044,7 +1225,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceRenewDBInstance", params)
+            headers = request.headers
+            body = self.call("InquiryPriceRenewDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceRenewDBInstanceResponse()
@@ -1072,7 +1254,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceUpgradeDBInstance", params)
+            headers = request.headers
+            body = self.call("InquiryPriceUpgradeDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceUpgradeDBInstanceResponse()
@@ -1100,7 +1283,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("IsolateDBInstances", params)
+            headers = request.headers
+            body = self.call("IsolateDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.IsolateDBInstancesResponse()
@@ -1128,7 +1312,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAccountRemark", params)
+            headers = request.headers
+            body = self.call("ModifyAccountRemark", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAccountRemarkResponse()
@@ -1156,7 +1341,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyBackupPlan", params)
+            headers = request.headers
+            body = self.call("ModifyBackupPlan", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyBackupPlanResponse()
@@ -1184,7 +1370,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceDeployment", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceDeployment", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceDeploymentResponse()
@@ -1212,7 +1399,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceName", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceName", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceNameResponse()
@@ -1240,7 +1428,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceParameters", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceParameters", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceParametersResponse()
@@ -1268,7 +1457,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceReadOnlyGroup", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceReadOnlyGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceReadOnlyGroupResponse()
@@ -1296,7 +1486,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceSpec", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceSpec", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceSpecResponse()
@@ -1324,7 +1515,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstancesProject", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstancesProject", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstancesProjectResponse()
@@ -1352,7 +1544,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyReadOnlyGroupConfig", params)
+            headers = request.headers
+            body = self.call("ModifyReadOnlyGroupConfig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyReadOnlyGroupConfigResponse()
@@ -1380,7 +1573,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySwitchTimePeriod", params)
+            headers = request.headers
+            body = self.call("ModifySwitchTimePeriod", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySwitchTimePeriodResponse()
@@ -1408,7 +1602,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("OpenDBExtranetAccess", params)
+            headers = request.headers
+            body = self.call("OpenDBExtranetAccess", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.OpenDBExtranetAccessResponse()
@@ -1436,7 +1631,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("OpenServerlessDBExtranetAccess", params)
+            headers = request.headers
+            body = self.call("OpenServerlessDBExtranetAccess", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.OpenServerlessDBExtranetAccessResponse()
@@ -1464,7 +1660,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RebalanceReadOnlyGroup", params)
+            headers = request.headers
+            body = self.call("RebalanceReadOnlyGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RebalanceReadOnlyGroupResponse()
@@ -1492,7 +1689,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RemoveDBInstanceFromReadOnlyGroup", params)
+            headers = request.headers
+            body = self.call("RemoveDBInstanceFromReadOnlyGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RemoveDBInstanceFromReadOnlyGroupResponse()
@@ -1520,7 +1718,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RenewInstance", params)
+            headers = request.headers
+            body = self.call("RenewInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RenewInstanceResponse()
@@ -1548,7 +1747,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ResetAccountPassword", params)
+            headers = request.headers
+            body = self.call("ResetAccountPassword", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ResetAccountPasswordResponse()
@@ -1576,7 +1776,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RestartDBInstance", params)
+            headers = request.headers
+            body = self.call("RestartDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RestartDBInstanceResponse()
@@ -1604,7 +1805,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetAutoRenewFlag", params)
+            headers = request.headers
+            body = self.call("SetAutoRenewFlag", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetAutoRenewFlagResponse()
@@ -1632,7 +1834,8 @@ class PostgresClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpgradeDBInstance", params)
+            headers = request.headers
+            body = self.call("UpgradeDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpgradeDBInstanceResponse()
